#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mod
version:              0.2.1.0
visibility:           public
id:                   mod-0.2.1.0-BE3AuDypE9eDiePIKR1Uoj
key:                  mod-0.2.1.0-BE3AuDypE9eDiePIKR1Uoj
license:              MIT
copyright:            2017-2022 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Andrew Lelechenko <andrew.lelechenko@gmail.com>
homepage:             https://github.com/Bodigrim/mod
synopsis:             Fast type-safe modular arithmetic
description:
    <https://en.wikipedia.org/wiki/Modular_arithmetic Modular arithmetic>,
    promoting moduli to the type level, with an emphasis on performance.
    Originally part of the <https://hackage.haskell.org/package/arithmoi arithmoi> package.

category:             Math, Number Theory
abi:                  944dd5d0f7922564f155e1df58c05989
exposed:              True
exposed-modules:      Data.Mod Data.Mod.Word
hidden-modules:       Data.Mod.Compat
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mod-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mod-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mod-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mod
hs-libraries:         HSmod-0.2.1.0-BE3AuDypE9eDiePIKR1Uoj
depends:
    base-4.18.2.1 deepseq-1.4.8.1 ghc-bignum-1.3
    primitive-0.9.1.0-5zbRYrfoFPr4oGDF3kIYIh
    semirings-0.7-3ApjPfVlrhJJwjCQvCOU12
    vector-0.13.2.0-HJSwbt845rQ2AOZrNm5BDk

haddock-interfaces:   /usr/share/doc/haskell-mod/html/mod.haddock
haddock-html:         /usr/share/doc/haskell-mod/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

